@@ -6,8 +6,7 @@ import jwt
 import requests
 import subprocess
 import warnings
-
-from rsa.cli import verify
+requests.packages.urllib3.disable_warnings()
 
 
 class FeatureStore:
